@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 from compose_x_common.compose_x_common import keyisset
 from troposphere import GetAtt, Ref
@@ -8,11 +7,13 @@ from troposphere.ecs import AuthorizationConfig, EFSVolumeConfiguration, Volume
 from troposphere.efs import AccessPoint, CreationInfo, PosixUser, RootDirectory
 from troposphere.iam import PolicyType
 
-from ecs_composex.common import add_parameters
-from ecs_composex.ecs.ecs_params import SERVICE_T, TASK_T
+from ecs_composex.common import add_parameters, setup_logging
+from ecs_composex.ecs.ecs_params import TASK_T
 from ecs_composex.efs.efs_params import FS_ARN, FS_ID, FS_MNT_PT_SG_ID, FS_PORT
 from ecs_composex.rds_resources_settings import handle_new_tcp_resource
 
+LOG = setup_logging()
+
 
 def get_volumes(task_definition):
     """
@@ -52,18 +53,10 @@ def add_task_iam_access_to_access_point(family, access_points, efs):
     """
     Function to add IAM Permissions to mount to EFS via AccessPoint for ECS Task
 
-    :param ecs_composex.common.compose_services.ComposeFamily family:
+    :param ecs_composex.ecs.ecs_family.ComposeFamily family:
     :param list<troposphere.efs.AccessPoint> access_points:
     :param ecs_composex.efs.efs_stack.Efs efs:
     """
-    service_definition = family.template.resources[SERVICE_T]
-    service_depends_on = (
-        getattr(service_definition, "DependsOn")
-        if hasattr(service_definition, "DependsOn")
-        else []
-    )
-    if not service_depends_on:
-        setattr(service_definition, "DependsOn", service_depends_on)
     policy = PolicyType(
         f"{family.logical_name}IamAccess",
         PolicyName=f"IamAccessToEfs{efs.logical_name}",
@@ -92,9 +85,8 @@ def add_task_iam_access_to_access_point(family, access_points, efs):
                 }
             ],
         },
-        Roles=[Ref(family.task_role.name["ImportParameter"])],
+        Roles=[family.iam_manager.task_role.name],
     )
-    service_depends_on.append(policy.title)
     family.template.add_resource(policy)
 
 
@@ -233,6 +225,11 @@ def expand_family_with_efs_volumes(efs_root_stack_title, new_efs, settings):
     fs_id_parameter = new_efs.attributes_outputs[FS_ID]["ImportParameter"]
     fs_id_getatt = new_efs.attributes_outputs[FS_ID]["ImportValue"]
     for target in new_efs.families_targets:
+        if target[0].service_compute.launch_type == "EXTERNAL":
+            LOG.warning(
+                f"x-efs - {target[0].name} - When using EXTERNAL Launch Type, networking settings cannot be set."
+            )
+            return
         access_points = []
         target[0].stack.Parameters.update({fs_id_parameter.title: fs_id_getatt})
         add_parameters(target[0].template, [fs_id_parameter])
@@ -279,15 +276,12 @@ def efs_to_ecs(resources, services_stack, res_root_stack, settings):
     :param ecs_composex.common.settings.ComposeXSettings settings:
     :return:
     """
-
-    new_resources = [
-        resources[res_name] for res_name in resources if not resources[res_name].lookup
-    ]
-    for new_res in new_resources:
-        handle_new_tcp_resource(
-            new_res,
-            res_root_stack,
-            port_parameter=FS_PORT,
-            sg_parameter=FS_MNT_PT_SG_ID,
-        )
-        expand_family_with_efs_volumes(res_root_stack.title, new_res, settings)
+    for resource_name, resource in resources.items():
+        LOG.info(f"{resource.module.res_key}.{resource_name} - Linking to services")
+        if not resource.mappings and resource.cfn_resource:
+            handle_new_tcp_resource(
+                resource,
+                port_parameter=FS_PORT,
+                sg_parameter=FS_MNT_PT_SG_ID,
+            )
+            expand_family_with_efs_volumes(res_root_stack.title, resource, settings)
