@@ -7,7 +7,7 @@ Module to handle Linking ECS tasks and the elastic cache clusters
 
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, List
+from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
     from ecs_composex.common.settings import ComposeXSettings
