@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 ecs_composex.rds parameters.
@@ -12,16 +11,9 @@ which it heavily relies onto.
 You can change the names *values* so you like so long as you keep it Alphanumerical [a-zA-Z0-9]
 """
 
-from os import path
-
 from ecs_composex.common.cfn_params import Parameter
-from ecs_composex.common.ecs_composex import X_KEY
 from ecs_composex.vpc.vpc_params import SG_ID_TYPE
 
-MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
-RES_KEY = f"{X_KEY}{MOD_KEY}"
-MAPPINGS_KEY = MOD_KEY
-
 DB_SECRET_POLICY_NAME = "RdsDbPolicy"
 DB_SECRET_T = "DBSecret"
 PARAMETER_GROUP_T = "DBParametersGroup"
@@ -98,3 +90,9 @@ DB_ENDPOINT_PORT = Parameter(
 )
 
 DB_SECRET_ARN = Parameter(DB_SECRET_T, Type="String")
+
+DB_CLUSTER_ARN_T = "DBClusterArn"
+DB_CLUSTER_ARN = Parameter(DB_CLUSTER_ARN_T, Type="String")
+
+DB_CLUSTER_NAME_T = "DBCluster"
+DB_CLUSTER_NAME = Parameter(DB_CLUSTER_NAME_T, Type="String")
